git

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Processor

type Processor struct {
	// contains filtered or unexported fields
}

Processor handles git operations on repositories

func NewProcessor

func NewProcessor(config *types.Config) *Processor

NewProcessor creates a new git operations processor

func (*Processor) AnalyzeRepo

func (p *Processor) AnalyzeRepo(repo *types.GitRepo)

AnalyzeRepo analyzes a git repository to determine its status

func (*Processor) ProcessRepo

func (p *Processor) ProcessRepo(ctx context.Context, repo types.GitRepo) types.GitRepo

ProcessRepo performs the git operation on a single repository

type Scanner

type Scanner struct {
	// contains filtered or unexported fields
}

Scanner handles discovering git repositories in a directory tree

func NewScanner

func NewScanner(config *types.Config) *Scanner

NewScanner creates a new git repository scanner

func (*Scanner) FindRepos

func (s *Scanner) FindRepos(ctx context.Context, rootPath string, onProgress func(int)) ([]types.GitRepo, error)

FindRepos discovers all git repositories in the given directory

Jump to