Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Processor ¶
type Processor struct {
// contains filtered or unexported fields
}
Processor handles git operations on repositories
func NewProcessor ¶
NewProcessor creates a new git operations processor
func (*Processor) AnalyzeRepo ¶
AnalyzeRepo analyzes a git repository to determine its status
type Scanner ¶
type Scanner struct {
// contains filtered or unexported fields
}
Scanner handles discovering git repositories in a directory tree
func NewScanner ¶
NewScanner creates a new git repository scanner
Click to show internal directories.
Click to hide internal directories.